platform_detail library

Classes

EnvironmentDetails
Typed wrapper for lightweight runtime environment details.
PlatformDetail
Allows you to determine platform details such as operating system or environment.
VersionDetails
Typed wrapper for app package metadata.

Enums

DeviceTheme
Groups in an enumerated list the type of theme the device is configured with.
PlatformGroup
It groups in an enumerated list the type of platform on which a Flutter application can be run.
PlatformType
Extended platform enum that includes web support.