EnvironmentDetails class

Typed wrapper for lightweight runtime environment details.

Constructors

EnvironmentDetails({required PlatformType platformType, required String platform, required String deviceModel, required String locale})
const

Properties

deviceModel String
final
hashCode int
The hash code for this object.
no setterinherited
locale String
final
platform String
final
platformType PlatformType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited